inferpy.datasets package
========================

Submodules
----------

inferpy.datasets.mnist module
-----------------------------

.. automodule:: inferpy.datasets.mnist
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: inferpy.datasets
   :members:
   :undoc-members:
   :show-inheritance:
